# py_me

**py_me** é uma biblioteca Python que oferece módulos para manipulação musical (`music_me`) e interfaces gráficas com Tkinter (`tk_me`).

## versão

**1.2.1** - *lançado em 1/10/2025*

## mudanças

- padronização dos Docstrings
- correção de alguns bugs
- Docstrings explicando o que tk_me e music_me fazem de forma mais detalhada
- adiciona um modelo de Docstring que explica bem como usar todas as funções disponives

## Instalação

```bash
pip install py-me